@@ -70,42 +70,9 @@ main (int argc, char* argv[])
 {
   int error_code = 0;
   char *libpath = NULL;
-  char *preload = NULL;
-  char *newpreload = NULL;
   char *newpath = NULL;
   int newlen = 0;
 
-  preload = getenv ("LD_PRELOAD");
-  
-  if (preload && preload[0] != '\0')
-    {
-      newlen += strlen (preload);
-      // for the separating ' '
-      newlen += 1;
-    }
-
-  newlen += sizeof (JAVA_HOME) - 1;
-  newlen += sizeof ("/lib//pr13212.so") - 1;
-  newlen += sizeof (ARCH) - 1;
-
-  newpreload = (char *) malloc (newlen + 1);
-
-  if (newpreload != NULL)
-    {
-      if (preload && preload[0] != '\0')
-        snprintf (newpreload, newlen + 1,
-                  "%s/lib/%s/pr13212.so %s", JAVA_HOME, ARCH, preload);
-      else
-        snprintf (newpreload, newlen + 1, "%s/lib/%s/pr13212.so", JAVA_HOME, ARCH);
-    }
-
-  // XXX commenting out LD_PRELOAD hack because of problems
-  // see http://gcc.gnu.org/bugzilla/show_bug.cgi?id=13212
-  // setenv ("LD_PRELOAD", newpreload, 1);
-
-  free (newpreload);
-
-
   newlen = 0;
 
   libpath = getenv ("LD_LIBRARY_PATH");
